/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.lang3.reflect.testbed;

/**
 * {@link GenericParent} subclass that explicitly specifies &lt;T&gt; as {@link String}.
 * @version $Id: StringParameterizedChild.java 1606051 2014-06-27 12:22:17Z ggregory $
 */
public class StringParameterizedChild extends GenericParent<String> {
    @Override
    public void consume(final String t) {
        super.consume(t);
    }
}
